export declare enum DialogPosition {
    center = 0,
    bottomLeft = 1,
    bottom = 2,
    bottomRight = 3
}
export interface DialogArgs {
    title: string;
    body: string;
    onClose?: () => void;
    modal?: boolean;
    okButton?: boolean;
    position?: DialogPosition;
}
/**
 * Create a dialog window with the given message.
 * Can be a modal (forces user interaction) or not.
 *
 * Usage:
 *     const dialog = new Dialog({
 *         title: 'the title',
 *         body: 'the body'
 *     });
 *     dialog.open();
 */
export declare class Dialog {
    private container;
    private title;
    private body;
    private overlay?;
    private onClose?;
    private keyUp?;
    private opened;
    constructor(args: DialogArgs);
    private createContainer;
    private createHorizontalRule;
    private createButtons;
    private createOverlay;
    private setupKeyboardShortcuts;
    private addKeyboardShortcuts;
    private removeKeyboardShortcuts;
    /**
     * Add the dialog to the page.
     */
    open(): void;
    /**
     * Remove the dialog from the page.
     */
    close(): void;
    /**
     * Check if the dialog is opened or not.
     */
    isOpened(): boolean;
    /**
     * Toggle between the open/close state.
     */
    toggle(): void;
    /**
     * Change the title of the dialog.
     */
    setTitle(title: string): void;
    /**
     * Change the body of the dialog.
     */
    setBody(body: string): void;
}
